@@ -19,7 +19,7 @@ case `tty` in
         consolechars --acm iso02
     else
         setfont lat2-16
-        setfont -m trivial
+        setfont -m trivial.trans
     fi
     loadkeys sr >/dev/null 2>&1
     echo -e -n "\\033(K" > `tty`
